#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun May 16 13:50:34 2021

@author: anton
"""

from SLiCAP import *
import values


#prj = initProject('Probe project')

fileName = 'ProbeNumeric'
#makeNetlist(fileName + '.asc', fileName)

# Create an instance of the instruction object
i1  = instruction()

# Define the circuit for this instruction and check its netlist
i1.setCircuit(fileName + '.cir')

# Overwrite the numeric values from the schematic with those given in values.py
i1.defPar('R_a', values.R_a)  
i1.defPar('R_b', values.R_scoop)
i1.defPar('C_a', values.C_a)
i1.defPar('C_b', values.C_b)
i1.defPar('L_g', values.L_gnd)
i1.defPar('R_s', values.R_src)

C_b_comp = values.C_a*values.R_a/values.R_scoop

# Display the circuit data on an HTML page
htmlPage("Circuit data")
head2html("Circuit diagram")
img2html('probe.jpg', 100)
img2html(fileName + ".svg", 500)
netlist2html(fileName + ".cir")
elementData2html(i1.circuit)
params2html(i1.circuit)

# Define the source and the detector, and the gain type.

i1.setSource('V1')
i1.setDetector('V_scope')
i1.setGainType('gain')

def stepParam(stepParameter):
    
    if stepParameter == 'cal':
        # Define and enable stepping of calibration +/-25%
        i1.setStepVar('C_b')
        i1.setStepStart(0.75*C_b_comp)
        i1.setStepStop(1.25*C_b_comp)
        i1.setStepNum(3)
        i1.setStepMethod('lin')
        i1.stepOn()
    
    elif stepParameter == 'gnd':
        # Define and enable stepping of ground wire inductance
        i1.setStepVar('L_g')
        i1.setStepStart(10e-9)
        i1.setStepStop(1e-6)
        i1.setStepNum(5)
        i1.setStepMethod('log')
        i1.stepOn()
    
    elif stepParameter == 'src':
        # Define and enable stepping of source resistance
        i1.setStepVar('R_s')
        i1.setStepStart(10)
        i1.setStepStop(1e3)
        i1.setStepNum(5)
        i1.setStepMethod('log')
        i1.stepOn()
    else:
        i1.stepOff()
        
stepDict = {'cal' : 'calibration', 'gnd': 'ground wire inductance', 
              'src': 'source resistance'}

stepParams = list(stepDict.keys())
stepParams.sort()

###############################################################################
#                                                                             #
# Frequency response versus detuningg, wire inductance, and source resistance #
#                                                                             #
###############################################################################

htmlPage('Frequency response')
head2html("Circuit diagram")
img2html('probe.jpg', 100)
img2html(fileName + ".svg", 500)

i1.setDataType('laplace')

for par in stepParams:
    
    head2html("Frequency response versus " + stepDict[par])
    stepParam(par)
    result = i1.execute()
    
    plotMag = plotSweep('dBmagProbe_' + par, 'dB magnitude characteristics ' +
                        'versus ' + stepDict[par], 
                        result, 100, 1e9, 200, funcType='dBmag', 
                        show=values.SHOW)
    
    plotPhs = plotSweep('phaseProbe_' + par, 'Phase characteristics '
                        'versus ' + stepDict[par],result, 
                        100, 1e9, 200, funcType='phase', show=values.SHOW)
    
    plotDly = plotSweep('delayProbe_' + par, 'Delay characteristics ' 
                        'versus ' +stepDict[par], result, 
                        100, 1e9, 200, funcType='delay', show=values.SHOW)
    
    plotDlyZoom = plotSweep('delayProbeZoom' + par, 'Delay characteristics ' +
                            'versus ' +stepDict[par], result, 1e6, 1e9, 200, 
                            funcType='delay', show=values.SHOW)
    
    fig2html(plotMag, 600)
    fig2html(plotPhs, 600)
    fig2html(plotDly, 600)
    fig2html(plotDlyZoom, 600)


###############################################################################
#                                                                             #
#   Poles and zeros versus detuning, wire inductance, and source resistance   #
#                                                                             #
###############################################################################

htmlPage('Poles and zeros')
head2html("Circuit diagram")
img2html('probe.jpg', 100)
img2html(fileName + ".svg", 500)

i1.setDataType('pz')

i1.stepOff()
result = i1.execute()
pz2html(result)

i1.setDataType('poles')

for par in stepParams:
    
    head2html("Pole positions versus " + stepDict[par])
    stepParam(par)
    result = i1.execute()
    
    polesPlot = plotPZ('polesProbe_' + par, 'Poles versus ' + stepDict[par], 
                       result, xmin=-500, xmax=0, ymin=-250, ymax=250, 
                       xscale='M', yscale = 'M', show=values.SHOW)
    polesPlotZoom = plotPZ('polesProbeZoom_' + par, 'Poles versus ' + 
                           stepDict[par], result, xmin=-2, xmax=0, ymin=-1, 
                           ymax=1, xscale='k', yscale='k', show=values.SHOW)
    
    fig2html(polesPlot, 600)
    fig2html(polesPlotZoom, 600)

###############################################################################
#                                                                             #
#    Step response versus detuning, wire inductance, and source resistance    #
#                                                                             #
###############################################################################

htmlPage('Unit step response')
head2html("Circuit diagram")
img2html('probe.jpg', 100)
img2html(fileName + ".svg", 500)

i1.setDataType('step')

for par in stepParams:
    
    head2html("Unit step response versus " + stepDict[par])
    stepParam(par)
    result = i1.execute()
    
    stepResp = plotSweep('stepRespProbe_' + par, 'Unit step response versus ' 
                         + stepDict[par], result, 0, 1, 200, sweepScale='m', 
                         yUnits='V', show=values.SHOW)
    
    stepZoom = plotSweep('stepZoomProbe_' + par, 'Unit step response  versus ' 
                         + stepDict[par], result, 0, 10, 200, sweepScale='n', 
                         yUnits='V', show=values.SHOW)
    
    fig2html(stepResp, 600)
    fig2html(stepZoom, 600)
